@@ -700,7 +700,7 @@ photos_application_activate_query_executed (GObject *source_object, GAsyncResult
   if (cursor == NULL)
     goto out;
 
-  photos_item_manager_add_item (PHOTOS_ITEM_MANAGER (self->state->item_mngr), cursor);
+  photos_item_manager_add_item (PHOTOS_ITEM_MANAGER (self->state->item_mngr), cursor, TRUE);
 
   identifier = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
   item = photos_base_manager_get_object_by_id (self->state->item_mngr, identifier);
@@ -1206,7 +1206,6 @@ photos_application_save_save (GObject *source_object, GAsyncResult *res, gpointe
   photos_export_notification_new (items, file);
 
  out:
-  photos_selection_controller_set_selection_mode (self->sel_cntrlr, FALSE);
   g_application_release (G_APPLICATION (self));
   g_clear_object (&file);
   g_list_free_full (items, g_object_unref);
@@ -1232,6 +1231,8 @@ photos_application_save_response (GtkDialog *dialog, gint response_id, gpointer
   item = photos_application_get_selection_or_active_item (self);
   g_return_if_fail (item != NULL);
 
+  photos_selection_controller_set_selection_mode (self->sel_cntrlr, FALSE);
+
   pictures_path = g_get_user_special_dir (G_USER_DIRECTORY_PICTURES);
   export_path = g_build_filename (pictures_path, PHOTOS_EXPORT_SUBPATH, NULL);
   export = g_file_new_for_path (export_path);
@@ -1382,6 +1383,8 @@ photos_application_share_response (GtkDialog *dialog, gint response_id, gpointer
   item = photos_application_get_selection_or_active_item (self);
   g_return_if_fail (item != NULL);
 
+  photos_selection_controller_set_selection_mode (self->sel_cntrlr, FALSE);
+
   g_application_hold (G_APPLICATION (self));
   g_application_mark_busy (G_APPLICATION (self));
   photos_share_point_share_async (share_point, item, NULL, photos_application_share_share, self);
