@@ -25,6 +25,8 @@
 
 #include "config.h"
 
+#include <string.h>
+
 #include <gio/gio.h>
 #include <glib.h>
 #include <tracker-sparql.h>
@@ -155,7 +157,7 @@ photos_item_manager_item_created_executed (GObject *source_object, GAsyncResult
   if (cursor == NULL)
     goto out;
 
-  photos_item_manager_add_item (self, cursor);
+  photos_item_manager_add_item (self, cursor, FALSE);
 
  out:
   g_clear_object (&cursor);
@@ -263,10 +265,10 @@ static gboolean
 photos_item_manager_cursor_is_collection (TrackerSparqlCursor *cursor)
 {
   gboolean ret_val;
-  const gchar *identifier;
+  const gchar *rdf_type;
 
-  identifier = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_IDENTIFIER, NULL);
-  ret_val = g_str_has_prefix (identifier, "photos:collection:");
+  rdf_type = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_RDF_TYPE, NULL);
+  ret_val = strstr (rdf_type, "nfo#DataContainer") != NULL;
   return ret_val;
 }
 
@@ -328,6 +330,50 @@ photos_item_manager_get_where (PhotosBaseManager *mngr, gint flags)
 }
 
 
+static void
+photos_item_manager_info_updated (PhotosBaseItem *item, gpointer user_data)
+{
+  PhotosItemManager *self = PHOTOS_ITEM_MANAGER (user_data);
+  PhotosBaseItem *updated_item;
+  gboolean is_collection;
+  gboolean is_favorite;
+  const gchar *id;
+
+  g_return_if_fail (PHOTOS_IS_BASE_ITEM (item));
+
+  id = photos_filterable_get_id (PHOTOS_FILTERABLE (item));
+  updated_item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), id));
+  g_return_if_fail (updated_item == item);
+
+  is_collection = photos_base_item_is_collection (item);
+  is_favorite = photos_base_item_is_favorite (item);
+
+  if (is_collection)
+    {
+      if (self->active_collection == NULL)
+        photos_base_manager_add_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_COLLECTIONS], G_OBJECT (item));
+    }
+  else
+    {
+      if (is_favorite)
+        photos_base_manager_add_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_FAVORITES], G_OBJECT (item));
+
+      photos_base_manager_add_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_OVERVIEW], G_OBJECT (item));
+    }
+
+  if (is_collection)
+    {
+      photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_FAVORITES], G_OBJECT (item));
+      photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_OVERVIEW], G_OBJECT (item));
+    }
+  else
+    {
+      if (self->active_collection == NULL)
+        photos_base_manager_remove_object (self->item_mngr_chldrn[PHOTOS_WINDOW_MODE_COLLECTIONS], G_OBJECT (item));
+    }
+}
+
+
 static void
 photos_item_manager_item_load (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -373,6 +419,7 @@ photos_item_manager_remove_object_by_id (PhotosBaseManager *mngr, const gchar *i
   if (item == NULL)
     return;
 
+  g_signal_handlers_disconnect_by_func (item, photos_item_manager_info_updated, self);
   g_object_ref (item);
 
   for (i = 0; self->item_mngr_chldrn[i] != NULL; i++)
@@ -697,15 +744,25 @@ photos_item_manager_activate_previous_collection (PhotosItemManager *self)
   g_signal_emit (self, signals[ACTIVE_COLLECTION_CHANGED], 0, self->active_collection);
 
   g_clear_object (&collection);
+
+  g_return_if_fail (self->active_collection == NULL);
+  g_return_if_fail (self->active_object == NULL);
 }
 
 
 void
-photos_item_manager_add_item (PhotosItemManager *self, TrackerSparqlCursor *cursor)
+photos_item_manager_add_item (PhotosItemManager *self, TrackerSparqlCursor *cursor, gboolean force)
 {
+  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
+  g_return_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor));
+
   if (photos_item_manager_cursor_is_collection (cursor))
     {
-      photos_item_manager_add_item_for_mode (self, PHOTOS_WINDOW_MODE_COLLECTIONS, cursor);
+      if (self->active_collection != NULL && force)
+        photos_item_manager_activate_previous_collection (self);
+
+      if (self->active_collection == NULL)
+        photos_item_manager_add_item_for_mode (self, PHOTOS_WINDOW_MODE_COLLECTIONS, cursor);
     }
   else
     {
@@ -722,12 +779,19 @@ photos_item_manager_add_item_for_mode (PhotosItemManager *self, PhotosWindowMode
 {
   PhotosBaseItem *item = NULL;
   PhotosBaseManager *item_mngr_chld;
+  gboolean is_collection;
   const gchar *id;
 
+  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
+  g_return_if_fail (TRACKER_SPARQL_IS_CURSOR (cursor));
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT);
   g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
 
+  is_collection = photos_item_manager_cursor_is_collection (cursor);
+  g_return_if_fail ((is_collection && (mode == PHOTOS_WINDOW_MODE_COLLECTIONS || mode == PHOTOS_WINDOW_MODE_SEARCH))
+                    || (!is_collection && (mode != PHOTOS_WINDOW_MODE_COLLECTIONS || self->active_collection != NULL)));
+
   item_mngr_chld = self->item_mngr_chldrn[mode];
   id = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_URN, NULL);
 
@@ -735,31 +799,84 @@ photos_item_manager_add_item_for_mode (PhotosItemManager *self, PhotosWindowMode
   if (item != NULL)
     {
       g_object_ref (item);
-      g_signal_emit_by_name (item_mngr_chld, "object-added", G_OBJECT (item));
     }
   else
     {
+      gboolean already_present = FALSE;
+
       item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (PHOTOS_BASE_MANAGER (self), id));
       if (item != NULL)
         {
           g_object_ref (item);
+          already_present = TRUE;
         }
       else
         {
           item = photos_item_manager_create_item (self, cursor);
           if (photos_base_item_is_collection (item))
             g_hash_table_insert (self->collections, g_strdup (id), g_object_ref (item));
+
+          g_signal_connect_object (item, "info-updated", G_CALLBACK (photos_item_manager_info_updated), self, 0);
         }
 
       photos_base_manager_add_object (item_mngr_chld, G_OBJECT (item));
       photos_base_manager_add_object (self->item_mngr_chldrn[0], G_OBJECT (item));
+
+      if (!already_present)
+        g_signal_emit_by_name (self, "object-added", G_OBJECT (item));
     }
 
-  g_signal_emit_by_name (self, "object-added", G_OBJECT (item));
   g_clear_object (&item);
 }
 
 
+void
+photos_item_manager_clear (PhotosItemManager *self, PhotosWindowMode mode)
+{
+  GHashTable *items;
+  GHashTableIter iter;
+  PhotosBaseManager *item_mngr_chld;
+  const gchar *id;
+
+  g_return_if_fail (PHOTOS_IS_ITEM_MANAGER (self));
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_NONE);
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT);
+  g_return_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW);
+
+  item_mngr_chld = self->item_mngr_chldrn[mode];
+  items = photos_base_manager_get_objects (item_mngr_chld);
+
+  g_hash_table_iter_init (&iter, items);
+  while (g_hash_table_iter_next (&iter, (gpointer *) &id, NULL))
+    {
+      PhotosBaseItem *item = NULL;
+      guint i;
+
+      for (i = 1; self->item_mngr_chldrn[i] != NULL; i++)
+        {
+          if (item_mngr_chld == self->item_mngr_chldrn[i])
+            continue;
+
+          item = PHOTOS_BASE_ITEM (photos_base_manager_get_object_by_id (self->item_mngr_chldrn[i], id));
+          if (item != NULL)
+            break;
+        }
+
+      if (item != NULL)
+        {
+          const gchar *id1;
+
+          id1 = photos_filterable_get_id (PHOTOS_FILTERABLE (item));
+          g_assert_cmpstr (id, ==, id1);
+
+          photos_base_manager_remove_object_by_id (self->item_mngr_chldrn[0], id);
+        }
+    }
+
+  photos_base_manager_clear (item_mngr_chld);
+}
+
+
 PhotosBaseItem *
 photos_item_manager_create_item (PhotosItemManager *self, TrackerSparqlCursor *cursor)
 {
@@ -823,6 +940,17 @@ photos_item_manager_get_collections (PhotosItemManager *self)
 }
 
 
+PhotosBaseManager *
+photos_item_manager_get_for_mode (PhotosItemManager *self, PhotosWindowMode mode)
+{
+  g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_NONE, NULL);
+  g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_EDIT, NULL);
+  g_return_val_if_fail (mode != PHOTOS_WINDOW_MODE_PREVIEW, NULL);
+
+  return self->item_mngr_chldrn[mode];
+}
+
+
 PhotosLoadState
 photos_item_manager_get_load_state (PhotosItemManager *self)
 {
